@@ -1,5 +1,5 @@
 package JPEG::JFIF;
-$JPEG::JFIF::VERSION = '0.9.3';
+$JPEG::JFIF::VERSION = '0.8';
 use strict;
 
 sub new {
@@ -31,11 +31,8 @@ sub get {
 		# int32 - Size
 		read(FILE,$buffer,4); 
 		my $size = unpack("N",substr($buffer,0,4));
-		$cl->{lastoctet} = $size;
 		
 		my $start = tell(FILE);
-		$cl->{last8binpos} = $start;
-		$cl->{lastsize} = $size;
 		for (my $i = 0; $i<$size;$i++) {
 		    seek(FILE,$start + $i,0);
 		    read(FILE,$buffer,1);
@@ -134,40 +131,14 @@ sub set_comment {
     my $old = $cl->get(2,120);
     my $header = $cl->get_raw("HEADER");
     my $buffer;
-    my $zero = 0;
-    my $newheader;
     
-    #$rest - tam gdzie sie zaczyna nastepny 8BIM za 2 120, czlyli 
-    my $rest = $cl->{lastsize} - $cl->{lastgetposafter} + $cl->{last8binpos};
-    
-    my $newlen = pack("n",length($new));
     #zmieniam dlugosc    
     # 22 to jest 0xFFED - zmienic na znalezienie i zamiane po tym, a nie tak na sztywno
     my $len = unpack("n",substr($header,22,2));
     $len = $len - length($old) + length($new);
-
-    # to pieprzone 0x00 ktore sie pojawia
-    # TEORETYCZNIE W MOIM ODCZUCIU TO POWINNO DZIALAC, ale nie wiem 
-    # jak to sie bedzie sprawowalo !!!! trzeba przetestowac.
-    #######################################################################
-    
-    if (((substr($header,$cl->{lastgetposafter}+$rest,1))) == 0) { $zero = 1; }
-
-    my $end = $zero;
-    for (my $ii=0;$ii<abs(length($old)-length($new));$ii++) { $end = !$end; }
-
-    if (!$end) { $len-- };
-
     substr($header,22,2) = pack("n",$len);
 
-    my $len2 = unpack("n",substr($header,48,2));
-    $len2 = $len2 - length($old) + length($new);
-    substr($header,48,2) = pack("n",$len2);
-
-    $newheader = substr($header,0,$cl->{lastgetpos}-2).$newlen.$new;
-    $newheader.= substr($header,$cl->{lastgetposafter},$rest);
-    if ($end == 1) { $newheader.=pack("C",0); }
-    $newheader.= substr($header,$cl->{lastgetposafter}+$rest+1);
+    my $newheader = substr($header,0,$cl->{lastgetpos}-2).pack("n",length($new)).$new.substr($header,$cl->{lastgetposafter});
     $cl->{header} = $newheader;
     return $newheader;
 }
@@ -185,29 +156,19 @@ sub write {
 
 __END__
 
-=head1 DOWNLOAD
-
-http://krzak.linux.net.pl/perl/JFIF-0.9.3.tar.gz
-
 =head1 NAME
 
 JPEG::JFIF - JFIF/JPEG tags operations.
 
 =head1 VERSION
 
-JFIF.pm v 0.9.3
+JFIF.pm v 0.8
 
 =head1 CHANGES
 
- 0.9.3 - another rule to workaround for that stupid 0x00 in APP14 (I couldn't find it in JFIF documentation)
- 0.9 - fix caption add 0x00 in some situations. I don't know what it is, But have to be.
  0.8 - can set comment (Caption) tag correctly (hihi)
  0.7 - can read all metatags
 
-=head1 SYNOPSIS
-
-This module can read and set additional info that is set by Adobe Photoshop in jpeg files (JFIF/JPEG format)
-
 =head1 DESCRIPTION
 
 This module can read and set additional info that is set by Adobe Photoshop in jpeg files (JFIF/JPEG format)
@@ -218,9 +179,8 @@ This module can read and set additional info that is set by Adobe Photoshop in j
     use strict;
 
     my $jfif = new JPEG::JFIF(filename=>"test.jpg");
-    
-    # this give you "caption" from adobe. All formats are described in IPTC-NAA specification.
-    my $caption = $jfif->get(2,120); 
+
+    my $caption = $jfif->get(2,120); # this give you "caption" from adobe. All formats are described in IPTC-NAA specification.
 
     $jfif->set_comment("this is my new caption");
 
